@@ -292,7 +292,10 @@ class SmsEntryDialog(object):
 
 		self._messagemodel = gtk.ListStore(gobject.TYPE_STRING)
 		self._messagesView = self._widgetTree.get_widget("smsMessages")
-		self._scrollWindow = self._messagesView.get_parent()
+
+		self._conversationView = self._messagesView.get_parent()
+		self._conversationViewPort = self._conversationView.get_parent()
+		self._scrollWindow = self._conversationViewPort.get_parent()
 
 		self._phoneButton = self._widgetTree.get_widget("phoneTypeSelection")
 		self._smsEntry = self._widgetTree.get_widget("smsEntry")
@@ -353,14 +356,16 @@ class SmsEntryDialog(object):
 			if parent is not None:
 				self._dialog.set_transient_for(parent)
 				parentSize = parent.get_size()
-				self._dialog.resize(parentSize[0], max(parentSize[1]-50, 100))
+				self._dialog.resize(parentSize[0], max(parentSize[1]-10, 100))
 
 			# Run
 			try:
-				self._dialog.show()
-				if messages:
-					self._messagesView.scroll_to_cell((len(messages)-1, ))
+				self._dialog.show_all()
 				self._smsEntry.grab_focus()
+				adjustment = self._scrollWindow.get_vadjustment()
+				dx = self._conversationView.get_allocation().height - self._conversationViewPort.get_allocation().height
+				dx = max(dx, 0)
+				adjustment.value = dx
 
 				if 1 < len(self._contactDetails):
 					if defaultIndex == -1:
@@ -371,7 +376,7 @@ class SmsEntryDialog(object):
 
 				userResponse = self._dialog.run()
 			finally:
-				self._dialog.hide()
+				self._dialog.hide_all()
 
 			# Process the users response
 			if userResponse == gtk.RESPONSE_OK and 0 <= self._numberIndex:
@@ -406,8 +411,10 @@ class SmsEntryDialog(object):
 		self._letterCountLabel.set_text(str(charsLeft))
 		if charsLeft < 0 or charsLeft == self.MAX_CHAR:
 			self._smsButton.set_sensitive(False)
+			self._dialButton.set_sensitive(True)
 		else:
 			self._smsButton.set_sensitive(True)
+			self._dialButton.set_sensitive(False)
 
 	def _request_number(self):
 		try:
@@ -1330,7 +1337,7 @@ class ContactsView(object):
 		assert self._backend.is_authed(), "Attempting to enable backend while not logged in"
 
 		self._contactsview.set_model(self._contactsmodel)
-		self._contactsview.set_fixed_height_mode(True)
+		self._contactsview.set_fixed_height_mode(False)
 		self._contactsview.append_column(self._contactColumn)
 		self._contactsviewselection = self._contactsview.get_selection()
 		self._contactsviewselection.set_mode(gtk.SELECTION_SINGLE)
